Changelog
=========

1.0.1 (2014-06-13)
------------------

- Metadata update.
  [thet]

1.0 (2012-11-07)
----------------

- Initial release
  [thet]


1.0pre
------

- When no description is set, return a BaseUnit as fallback. Fixes
  AttributeError, where original_encoding was tried to accessed on a string
  value.
  [thet]

- Register the skins folder for any theme.
  [thet]

- Initial version on 2010-10-05 for sfd.at.
